from .. import Provider as BaseProvider


class Provider(BaseProvider):
    # jobs parsed from a list provided by State Treasury:
    # http://www.valtiokonttori.fi/download/noname/%7BF69EA5BD-C919-49FE-8D51-91434E4B030D%7D/82158
    jobs = ["Agrologi",
            "Aikuiskoulutusjohtaja",
            "Aineenopettaja",
            "Ajojärjestelijä",
            "Akatemian tutkijatohtori",
            "Aktuaari",
            "Alakoulujen apulaisrehtori",
            "Alikersantti",
            "Alkoholiasiain ylitarkastaja",
            "Back office asiantuntija",
            "Ballistikko",
            "Bioanalyytikko",
            "Brand manager",
            "Budjettiassistentti",
            "Business controller",
            "Cc-yritysneuvoja",
            "Cert-fi -yksikön päällikkö",
            "Communication officer",
            "Consul",
            "Counsellor",
            "Data-analyytikko",
            "Dekaanin sihteeri",
            "Dieettikeittäjä",
            "Digitaalisen kokeen toteuttaja",
            "Diplomi-insinööri",
            "Dokumentoija",
            "Dosentti",
            "Eakr-koordinaattori",
            "Editoija",
            "Edunvalvontasihteeri",
            "Egr-ohjaaja",
            "Ekokampuskoordinaattori",
            "Elektroniikka-asentaja",
            "Elinkeinopäällikkö",
            "Elokuvakonemestari",
            "Elputeknikko",
            "Eläinlääkintöneuvos",
            "Faktori",
            "Farmakologi",
            "Fidipro-professori",
            "Filmiteknikko",
            "Financial controller",
            "Floristi",
            "Fysioterapeutti",
            "Fyysikko",
            "Gemmologi",
            "Gentax-järjestelmäasiantuntija",
            "Geofyysikko",
            "Gis-asiantuntija",
            "Gm huto pääkäyttäjä",
            "Graafikko",
            "Haastattelija",
            "Hakukoordinaattori",
            "Hallimestari",
            "Hammashoitaja",
            "Hankearkkitehti",
            "Harjaantumisopetuksen erityisluokanopettaja",
            "Havainnontarkastaja",
            "Helikopterihuoltoaliupseeri",
            "Henkikirjoittaja",
            "Johtava kuluttajaoikeusneuvoja",
            "Ict-arkkitehti",
            "Ihmisoikeuskeskuksen johtaja",
            "Iktyonomi",
            "Ilma-aluksen päällikkö",
            "Iltapäiväkerhon ohjaaja",
            "Immunologi",
            "Info-palvelupisteen hoitaja",
            "Innoittaja",
            "Jakeluvastaava",
            "Jalkaväen tarkastaja",
            "Jaoksen johtaja",
            "Jatkokoulutettava eläinlääkäri",
            "Jhs-projektipäällikkö",
            "Johdon asiantuntija",
            "Joukkoliikenneasiantuntija",
            "Julkaisu- ja markkinointisuunnittelija",
            "Junamies",
            "Juontaja",
            "Kaapeli-insinööri",
            "Kabinettisihteeri",
            "Kadettikoulun johtaja",
            "Kahvila-apulainen",
            "Kairaaja",
            "Kalabiologi",
            "Kampanjapäällikkö",
            "Kanavanhoitaja",
            "Kapellimestari",
            "Karjamestari",
            "Laadunvarmistuksen asiantuntija",
            "Laboraattori",
            "Laillisuusvalvontasihteeri",
            "Laki- ja henkilöstöasiainjohtaja",
            "Lapsiasiavaltuutettu",
            "Laskennan kehittämispäällikkö",
            "Lataamoinsinööri",
            "Lautakuntasihteeri",
            "Lavastaja",
            "Maa- ja vesirakennustyöntekijä",
            "Maisema-arkkitehti",
            "Majakkateknikko",
            "Maksatusasiantuntija",
            "Malli",
            "Mareografihoitaja",
            "Mastoteknikko",
            "Matemaatikko",
            "Media- ja kulttuurikoordinaattori",
            "Neuropsykologi",
            "Nimikkeistöpäällikkö",
            "Nosturinkuljettaja",
            "Notaari",
            "Nukutuslääkäri",
            "Numerointisihteeri",
            "Nuorempi konstaapeli",
            "Näytearkistonhoitaja",
            "Näönkäytön asiantuntija",
            "Obduktiokoordinaattori",
            "Observaattori",
            "Offset-monistaja",
            "Ohjaaja",
            "Oikaisulautakunnan puheenjohtaja",
            "Oleskelulupakäsittelijä",
            "Omistajaohjausyksikön johtaja",
            "Ompelija",
            "Opas",
            "Operaatiopäällikkö",
            "Padonhoitaja",
            "Paikallisjohtaja",
            "Pakolaiskeskuksen johtaja",
            "Palkanlaskentapäällikkö",
            "Panostaja",
            "Paperikonservaattori",
            "Parturi-kampaaja",
            "Passi- ja maahantulolupavirkailija/toimistovirkailija",
            "Pataljoonan komentaja",
            "Pedagogi",
            "Radioasentaja",
            "Rahakammion johtaja",
            "Raideliikennejohtaja",
            "Rajaeläinlääkäri",
            "Rakennemuutosjohtaja",
            "Raportoinnin asiantuntija",
            "Ratainsinööri",
            "Rauhanturvaaja",
            "Ravintohaastattelija",
            "Rehtori",
            "Saamelaisarkistonhoitaja",
            "Sadehavainnontekijä",
            "Sairaala-apulainen",
            "Saksan, englannin ja ruotsinkielen lehtori",
            "Salkunhoitaja",
            "Sanomakeskusaliupseeri",
            "Satamapäällikkö",
            "Seismologi",
            "Sektorijohtaja",
            "Selvittelijä",
            "Taajuussuunnittelija",
            "Taideamanuenssi",
            "Tallentaja",
            "Tanssija",
            "Tapahtumakoordinaattori",
            "Tarjoilija",
            "Tasa-arvoneuvos",
            "Tavaraliikennelupakäsittelijä",
            "Team finland kasvu- ja kansainvälistymiskoordinaattori",
            "Teemapäällikkö",
            "Ulkoasiainneuvos",
            "Ulosottojohtaja",
            "Ultraäänihoitaja",
            "Unix-asiantuntija",
            "Upseeri",
            "Urakonsultti",
            "Urheiluohjaaja",
            "Vaaitsija",
            "Vac-yhdyshenkilö",
            "Vahingonkorvausasiantuntija",
            "Vaihteenhoitaja",
            "Vakuustoimittaja",
            "Valaistusmestari",
            "Vammaisasiamies",
            "Vanhempi tutkijainsinööri",
            "Vapaa-ajan ohjaaja",
            "Varadekaani",
            "Www-asiantuntija",
            "Yhdenvertaisuusvaltuutettu",
            "Yhteinen tuntiopettaja",
            "Yksikkösihteeri",
            "Yleinen edunvalvoja",
            "Yliaktuaari",
            "Ylläpidon palvelupäällikkö",
            "Yläasteen rehtori",
            "Ympärintönsuojeluyksikön päällikkö",
            "Yrittäjyysneuvoja",
            "Yva-koordinaattori"]
